<?php

namespace EventPortal\Domain\Util;

use EventPortal\Domain\Component\Input;
use EventPortal\Domain\Component\Section;
use EventPortal\Domain\Component\Step;

class ValidationRules
{
    /**
     * Returns rules for fields.
     */
    public static function for(array $fields): array
    {
        return collect($fields)
            ->map(function ($field) {
                if ($field instanceof Step) {
                    return self::handleSteps($field);
                }

                if ($field instanceof Section) {
                    return $field->children;
                }

                return $field;
            })
            ->flatten()
            ->mapWithKeys(function (Input $input) {
                return [
                    $input->name => $input->validation,
                ];
            })
            ->filter()
            ->toArray();
    }

    /**
     * @param mixed $field
     * @return mixed
     */
    private static function handleSteps($field)
    {
        $containsSections = collect($field->children)
            ->filter(function ($item) {
                return $item instanceof Section;
            })
            ->isNotEmpty();

        if ($containsSections) {
            return collect($field->children)->pluck('children')->flatten();
        }

        return $field->children;
    }
}
