<?php

namespace EventPortal\Tests\Feature\Admin\Event\Form;

use EventPortal\Domain\Agenda\Models\Pathway;
use EventPortal\Domain\Component\Option;
use EventPortal\Domain\Event\Form\Enums\FormType;
use EventPortal\Domain\Event\Form\Models\Form;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Tests\Support\Traits\SeedRolesAndPermissions;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class CreateFormTest extends TestCase
{
    use RefreshDatabase, SeedRolesAndPermissions;

    /** @test **/
    public function can_create_a_form(): void
    {
        $event = factory(Event::class)->create();
        Pathway::generate($event, Pathway::DEFAULT, 'Default pathway');

        $this
            ->actingAsSuperAdmin()
            ->post(route('admin.form.store', $event->id), $this->getFormData());

        $form = Form::first();
        $this->assertEquals('Test Form', $form->name);
        $this->assertEquals(FormType::Registration()->getValue(), $form->getRawOriginal('type'));
    }

    private function getFormData(): array
    {
        return [
            'name' => 'Test Form',
            'type' => Option::make(FormType::Registration()->getValue())->toArray(),
        ];
    }

    /** @test **/
    public function slug_auto_generated_from_name(): void
    {
        $event = factory(Event::class)->create();
        Pathway::generate($event, Pathway::DEFAULT, 'Default pathway');

        $this
            ->actingAsSuperAdmin()
            ->followingRedirects()
            ->post(route('admin.form.store', $event->id), $this->getFormData());

        $form = Form::first();
        $this->assertEquals('test-form', $form->slug);
    }
}
